@@ -10,7 +10,7 @@ class Respuesta(BaseModel):
     fecha_oper: int
     err_codigo: types.CodigoError
     err_descripcion: str
-    categoria: types.CategoriaOrdenPago
+    categoria: types.CategoriaRespuesta
 
     class Config:  # noqa: WPS306, WPS431
         use_enum_values = True
@@ -33,11 +33,11 @@ class Respuesta(BaseModel):
         return mensaje
 
     @classmethod
-    def parse_xml(cls, mensaje):
-        respuesta = mensaje.find('respuesta')
+    def parse_xml(cls, mensaje_element):
+        respuesta = mensaje_element.find('respuesta')
 
         respuesta_data = {
-            'categoria': mensaje.attrib['categoria'],
+            'categoria': mensaje_element.attrib['categoria'],
         }
 
         for sub_element in respuesta.getchildren():
